muuntaja.parse


fast-memoizeclj

(fast-memoize size f)
source

parse-acceptclj

(parse-accept accept-header)

Parse Accept headers into a sorted sequence of content-types. "application/json;level=1;q=0.4" => ("application/json"})

Parse Accept headers into a sorted sequence of content-types.
"application/json;level=1;q=0.4"
=> ("application/json"})
sourceraw docstring

parse-accept-charsetclj

(parse-accept-charset s)
source

parse-content-typeclj

(parse-content-type s)
source

cljdoc builds & hosts documentation for Clojure/Script libraries