(parse-accept accept-header)Parse Accept headers into a sorted sequence of content-types. "application/json;level=1;q=0.4" => ("application/json"})
Parse Accept headers into a sorted sequence of content-types.
"application/json;level=1;q=0.4"
=> ("application/json"})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |